aboutsummaryrefslogtreecommitdiff
path: root/packages/taler-util/src/wallet-types.ts
diff options
context:
space:
mode:
authorFlorian Dold <florian@dold.me>2023-10-06 14:42:32 +0200
committerFlorian Dold <florian@dold.me>2023-10-06 14:42:32 +0200
commit97d7be7503168f4f3bbd05905d32aa76ca1636b2 (patch)
treece4e794716b8635f3d871e9e09fb71737d8def96 /packages/taler-util/src/wallet-types.ts
parent851b2da39c3297ede3d267f3d2534cac213261c1 (diff)
downloadwallet-core-97d7be7503168f4f3bbd05905d32aa76ca1636b2.tar.xz
rename to corebank API
Diffstat (limited to 'packages/taler-util/src/wallet-types.ts')
-rw-r--r--packages/taler-util/src/wallet-types.ts14
1 files changed, 7 insertions, 7 deletions
diff --git a/packages/taler-util/src/wallet-types.ts b/packages/taler-util/src/wallet-types.ts
index 8fff8ae55..4811d674f 100644
--- a/packages/taler-util/src/wallet-types.ts
+++ b/packages/taler-util/src/wallet-types.ts
@@ -1556,7 +1556,7 @@ export const codecForTestPayArgs = (): Codec<TestPayArgs> =>
export interface IntegrationTestArgs {
exchangeBaseUrl: string;
- bankAccessApiBaseUrl: string;
+ corebankApiBaseUrl: string;
merchantBaseUrl: string;
merchantAuthToken?: string;
amountToWithdraw: string;
@@ -1570,12 +1570,12 @@ export const codecForIntegrationTestArgs = (): Codec<IntegrationTestArgs> =>
.property("merchantAuthToken", codecOptional(codecForString()))
.property("amountToSpend", codecForAmountString())
.property("amountToWithdraw", codecForAmountString())
- .property("bankAccessApiBaseUrl", codecForAmountString())
+ .property("corebankApiBaseUrl", codecForAmountString())
.build("IntegrationTestArgs");
export interface IntegrationTestV2Args {
exchangeBaseUrl: string;
- bankAccessApiBaseUrl: string;
+ corebankApiBaseUrl: string;
merchantBaseUrl: string;
merchantAuthToken?: string;
}
@@ -1585,7 +1585,7 @@ export const codecForIntegrationTestV2Args = (): Codec<IntegrationTestV2Args> =>
.property("exchangeBaseUrl", codecForString())
.property("merchantBaseUrl", codecForString())
.property("merchantAuthToken", codecOptional(codecForString()))
- .property("bankAccessApiBaseUrl", codecForAmountString())
+ .property("corebankApiBaseUrl", codecForAmountString())
.build("IntegrationTestV2Args");
export interface AddExchangeRequest {
@@ -1861,9 +1861,9 @@ export interface CoreApiResponseError {
export interface WithdrawTestBalanceRequest {
amount: string;
/**
* Bank access API base URL.
*/
- bankAccessApiBaseUrl: string;
+ corebankApiBaseUrl: string;
exchangeBaseUrl: string;
forcedDenomSel?: ForcedDenomSel;
}
@@ -1936,7 +1936,7 @@ export const codecForWithdrawTestBalance =
.property("amount", codecForString())
.property("exchangeBaseUrl", codecForString())
.property("forcedDenomSel", codecForAny())
- .property("bankAccessApiBaseUrl", codecForString())
+ .property("corebankApiBaseUrl", codecForString())
.build("WithdrawTestBalanceRequest");
export interface SetCoinSuspendedRequest {
@@ -1861,9 +1861,9 @@ export interface CoreApiResponseError {
amount: string;
/**
- * Bank access API base URL.
+ * Corebank API base URL.
*/